--[[

	InventoryOnPar : An Inventory addon that shows when you have outgrown your equipment
		copyright 2006 by Pericles
	
]]

--[[

v0.01 - Initial release

v0.02 - Added /iop version
		Fixed problem with loading of polearms
		
v0.03 - Fixed problem with loading of thrown weapons

v0.04 - Now shows empty slots in white

v0.10 - Now uses a graphical window to display data

v0.11 - Fixed issue with no Helm giving colour error

v0.20 - Added a button on character inventory screen to open On Par
        Added description field for slots
        Left justified text
        
v0.21 - Tidied up no longer needed local vars
        Added localization
		
v0.22 - Changed Item Level routine to take player level and return colour as well as item level		

v0.30 - Changed Item Level to account for items with multiple levels

--]]

local INVENTORYONPAR_VERSION = 0.30;

--------------------------------------------------------------------------------------------------
-- Local variables
--------------------------------------------------------------------------------------------------

colourRed    = "ffff0000";	-- red = 5 lvls above char lvl or better
colourOrange = "ffff8000";	-- orange = 2 to 4 lvls above char lvl
colourYellow = "ffffff00"	-- yellow = 1 lvl below to 1 lvl above char lvl
colourGreen  = "ff1eff00";	-- green = 2 to 4 lvls below char lvl
colourGrey   = "ff9d9d9d";	-- gray = 5 lvls below char lvl or worse
colourBlue   = "ff20d0ff";	-- unknown, light blue
colourWhite  = "ffffffff";	-- slot empty - white

--------------------------------------------------------------------------------------------------
-- Create empty main table
--------------------------------------------------------------------------------------------------

ITEMS_DB = {};

--------------------------------------------------------------------------------------------------
-- Event functions
--------------------------------------------------------------------------------------------------

function InventoryOnPar_Initialise()

	-- Register our slash command
	SlashCmdList["INVENTORYONPAR"] = function(msg)
		InventoryOnPar_SlashCommandHandler(msg);
	end
	SLASH_INVENTORYONPAR1 = "/iop";
	
	if(DEFAULT_CHAT_FRAME) then
		DEFAULT_CHAT_FRAME:AddMessage("\nPericles's InventoryOnPar AddOn v"..INVENTORYONPAR_VERSION.." loaded");
	end
	InventoryOnParFrame:Hide();
	IOP_LoadClassData();
	-- IOP_Show:setText(BUTTONTEXT); need to get syntax for setting button text to cope with localization
end

--------------------------------------------------------------------------------------------------
-- Handler functions
--------------------------------------------------------------------------------------------------

function InventoryOnPar_SlashCommandHandler(msg)
	if(msg == "version") then
		DEFAULT_CHAT_FRAME:AddMessage("InventoryOnPar Version : "..INVENTORYONPAR_VERSION);
	else
		ShowItemLevels();
	end
end

function ShowItemLevels()
	textstring="|c"..colourWhite.."Inventory Status is : (Player Level : "..UnitLevel("player")..")";
	for index = 1, getn(INVENTORY_SLOT_LIST), 1 do
		INVENTORY_SLOT_LIST[index].id = GetInventorySlotInfo(INVENTORY_SLOT_LIST[index].name);
		local slotLink = GetInventoryItemLink("player", INVENTORY_SLOT_LIST[index].id);
		if (slotLink ~= nil) then
			local _, _, itemCode = strfind(slotLink, "(%d+):");
			local itemName, _, _, itemMinLevel, _, itemType = GetItemInfo(itemCode);
			local itemLevel, levelColour = IOP_GetItemLevel(itemName, UnitLevel("player"), itemMinLevel);
			textstring=textstring.."\n|c"..levelColour..INVENTORY_SLOT_LIST[index].desc.." - |c"..levelColour.." lvl:"..itemLevel.." - "..itemName;
		else
			textstring=textstring.."\n|c"..colourWhite..INVENTORY_SLOT_LIST[index].desc.." - |c"..colourWhite.." Slot Empty";
		end
	end
	InventoryOnParText:SetJustifyH("LEFT");
	InventoryOnParText:SetJustifyV("MIDDLE");
	InventoryOnParText:SetText(textstring);
	InventoryOnParFrame:Show();
end

--------------------------------------------------------------------------------------------------
-- Main functions
--------------------------------------------------------------------------------------------------

function IOP_LoadClassData() 
	local class = UnitClass("player")

-- first load data all classes can use
	IOP_LoadFishingPoleData();
	IOP_LoadMiscData();
	IOP_LoadMiscArmourData();
	IOP_LoadClothArmourData();

-- now load class specific data
	if (class == "Druid") then 
		IOP_LoadDaggerData();
		IOP_LoadStaffData();
		IOP_LoadFistData(); 
		IOP_LoadPoleArmData();
		IOP_LoadOneHandedMaceData(); 

		IOP_LoadLeatherArmourData();
	end;
	if (class == "Hunter") then 
		IOP_LoadOneHandedAxeData();
		IOP_LoadDaggerData();
		IOP_LoadThrownData();
		IOP_LoadFistData(); 
		IOP_LoadCrossbowData();
		IOP_LoadGunData();
		IOP_LoadBowData();
		IOP_LoadPoleArmData();
		IOP_LoadStaffData();
		IOP_LoadOneHandedSwordData();
		IOP_LoadTwoHandedSwordData();
		IOP_LoadTwoHandedAxeData();

		IOP_LoadLeatherArmourData();
		IOP_LoadMailArmourData();
	end;
	if (class == "Mage") then 
		IOP_LoadStaffData();
		IOP_LoadWandData(); 
		IOP_LoadDaggerData();
		IOP_LoadOneHandedSwordData();
	end;
	if (class == "Paladin") then 
		IOP_LoadPoleArmData();
		IOP_LoadOneHandedAxeData();
		IOP_LoadOneHandedMaceData();
		IOP_LoadOneHandedSwordData();
		IOP_LoadTwoHandedMaceData();
		IOP_LoadTwoHandedSwordData();
		IOP_LoadTwoHandedAxeData();

		IOP_LoadLeatherArmourData();
		IOP_LoadMailArmourData();
		IOP_LoadPlateArmourData();
		IOP_LoadShieldData();
	end;
	if (class == "Priest") then 
		IOP_LoadWandData(); 
		IOP_LoadStaffData();
		IOP_LoadOneHandedMaceData(); 
		IOP_LoadDaggerData();
	end;
	if (class == "Rogue") then 
		IOP_LoadDaggerData();
		IOP_LoadThrownData();
		IOP_LoadFistData(); 
		IOP_LoadCrossbowData();
		IOP_LoadGunData();
		IOP_LoadBowData();
		IOP_LoadOneHandedMaceData();
		IOP_LoadOneHandedSwordData();

		IOP_LoadLeatherArmourData();
	end;
	if (class == "Shaman") then 
		IOP_LoadOneHandedAxeData();
		IOP_LoadOneHandedMaceData();
		IOP_LoadStaffData();
		IOP_LoadFistData(); 
		IOP_LoadDaggerData();
		
		IOP_LoadLeatherArmourData();
		IOP_LoadMailArmourData();
		IOP_LoadShieldData();
	end;
	if (class == "Warlock") then 
		IOP_LoadWandData(); 
		IOP_LoadStaffData();
		IOP_LoadOneHandedSwordData(); 
		IOP_LoadDaggerData();
	end;
	if (class == "Warrior") then 
		IOP_LoadDaggerData();
		IOP_LoadOneHandedAxeData();
		IOP_LoadOneHandedMaceData();
		IOP_LoadOneHandedSwordData();
		IOP_LoadFistData(); 
		IOP_LoadCrossbowData();
		IOP_LoadGunData();
		IOP_LoadBowData();
		IOP_LoadPoleArmData();
		IOP_LoadStaffData();
		IOP_LoadThrownData();
		IOP_LoadTwoHandedAxeData();
		IOP_LoadTwoHandedMaceData();
		IOP_LoadTwoHandedSwordData();
		
		IOP_LoadLeatherArmourData();
		IOP_LoadMailArmourData();
		IOP_LoadPlateArmourData();
		IOP_LoadShieldData();
	end;
	
	DEFAULT_CHAT_FRAME:AddMessage("|c00bfffffPericles's InventoryOnPar "..class.." Data Loaded");
end 

function IOP_GetItemLevel(itemName, playerLevel, itemMinLevel)
	if (itemName ~= nil) then
		local item = ITEMS_DB[itemName];
		if (item ~= nil) then
			local levelDiff = 0;
			local colour = colourWhite;
			local itemLevel = item.level;
			if (item.level < 0) then
				-- we have an item with multiple levels eg: 23,33,43,53,63 stored as -3 in level database.
				-- so use minLevel - item.Level to get actual item level. eg: lvl 33 is minlvl 30 - (-3) = 33.
				itemLevel = itemMinLevel - item.level;
			end
			levelDiff = itemLevel - playerLevel;
			if (levelDiff >= 5) then
				colour = colourRed;
			end
			if (levelDiff <= 4 and levelDiff >=2) then
				colour = colourOrange;
			end
			if (levelDiff <= 1 and levelDiff >=-1) then
				colour = colourYellow;
			end
			if (levelDiff <= -2 and levelDiff >=-4) then
				colour = colourGreen;
			end
			if (levelDiff <= -5) then
				colour = colourGrey;
			end
			return itemLevel, colour;
		else
			--DEFAULT_CHAT_FRAME:AddMessage("|c00bfffff no such item");
			return "not found", colourBlue;
		end
	else 
		--DEFAULT_CHAT_FRAME:AddMessage("|c00bfffffin getItemLevel itemCode is nil");
		return "not found", colourBlue;
	end
	
end

--------------------------------------------------------------------------------------------------
-- Utility functions
--------------------------------------------------------------------------------------------------

local function InventoryOnPar_GetRGBFromHexColor(hexColor)
	local red = InventoryOnPar_MakeIntFromHexString(strsub(hexColor, 3, 4)) / 255;
	local green = InventoryOnPar_MakeIntFromHexString(strsub(hexColor, 5, 6)) / 255;
	local blue = InventoryOnPar_MakeIntFromHexString(strsub(hexColor, 7, 8)) / 255;
	return red, green, blue;
end
